Package: PatientLevelPrediction
Type: Package
Title: Develop Clinical Prediction Models Using the Common Data Model
Version: 6.6.0
Date: 2026-03-09
Authors@R: c(
    person("Egill", "Fridgeirsson", email = "e.fridgeirsson@erasmusmc.nl", role = c("aut", "cre")),
    person("Jenna", "Reps", email = "jreps@its.jnj.com", role = c("aut")),
    person("Martijn", "Schuemie", role = c("aut")),
    person("Marc", "Suchard", role = c("aut")),
    person("Patrick", "Ryan", role = c("aut")),
    person("Peter", "Rijnbeek", role = c("aut")),
    person("Observational Health Data Science and Informatics", role = c("cph")))
Description: A user friendly way to create patient level prediction models using
  the Observational Medical Outcomes Partnership Common Data Model. Given a cohort
  of interest and an outcome of interest, the package can use data in the Common
  Data Model to build a large set of features. These features can then be used to
  fit a predictive model with a number of machine learning algorithms. This is
  further described in Reps (2017) <doi:10.1093/jamia/ocy032>.
License: Apache License 2.0
URL: https://ohdsi.github.io/PatientLevelPrediction/,
        https://github.com/OHDSI/PatientLevelPrediction
BugReports: https://github.com/OHDSI/PatientLevelPrediction/issues
VignetteBuilder: knitr
Depends: R (>= 4.0.0)
Imports: Andromeda, Cyclops (>= 3.0.0), DatabaseConnector (>= 6.0.0),
        digest, dplyr, FeatureExtraction (>= 3.0.0), Matrix, memuse,
        ParallelLogger (>= 2.0.0), pROC, PRROC, rlang, SqlRender (>=
        1.1.3), tidyr, utils
Suggests: curl, Eunomia (>= 2.0.0), glmnet, ggplot2, gridExtra,
        IterativeHardThresholding, knitr, lightgbm, Metrics, mgcv,
        OhdsiShinyAppBuilder (>= 1.0.0), parallel, pkgload, polspline,
        readr, ResourceSelection, ResultModelManager (>= 0.6.0),
        reticulate (>= 1.41), rmarkdown, RSQLite, scoring, survival,
        survminer, testthat, withr, xgboost (> 1.3.2.1)
RoxygenNote: 7.3.3
Encoding: UTF-8
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-09 14:10:30 UTC; egill
Author: Egill Fridgeirsson [aut, cre],
  Jenna Reps [aut],
  Martijn Schuemie [aut],
  Marc Suchard [aut],
  Patrick Ryan [aut],
  Peter Rijnbeek [aut],
  Observational Health Data Science and Informatics [cph]
Maintainer: Egill Fridgeirsson <e.fridgeirsson@erasmusmc.nl>
Repository: CRAN
Date/Publication: 2026-03-09 15:20:02 UTC
Built: R 4.6.0; ; 2026-04-30 15:02:32 UTC; unix
