# Generated by roxygen2: do not edit by hand

S3method(print,plpData)
S3method(print,summary.plpData)
S3method(summary,plpData)
export(MapIds)
export(averagePrecision)
export(brierScore)
export(calibrationLine)
export(computeAuc)
export(computeAuprc)
export(computeGridPerformance)
export(configurePython)
export(covariateSummary)
export(createCohortCovariateSettings)
export(createDatabaseDetails)
export(createDatabaseSchemaSettings)
export(createDefaultExecuteSettings)
export(createDefaultSplitSetting)
export(createExecuteSettings)
export(createExistingSplitSettings)
export(createFeatureEngineeringSettings)
export(createGlmModel)
export(createHyperparameterSettings)
export(createIterativeImputer)
export(createLearningCurve)
export(createLogSettings)
export(createModelDesign)
export(createNormalizer)
export(createPlpResultTables)
export(createPreprocessSettings)
export(createRandomForestFeatureSelection)
export(createRareFeatureRemover)
export(createRestrictPlpDataSettings)
export(createSampleSettings)
export(createSklearnIterativeImputer)
export(createSimpleImputer)
export(createSklearnModel)
export(createSplineSettings)
export(createStratifiedImputationSettings)
export(createStudyPopulation)
export(createStudyPopulationSettings)
export(createTempModelLoc)
export(createTuningMetric)
export(createUnivariateFeatureSelection)
export(createValidationDesign)
export(createValidationSettings)
export(diagnoseMultiplePlp)
export(diagnosePlp)
export(evaluatePlp)
export(externalValidateDbPlp)
export(extractDatabaseToCsv)
export(fitPlp)
export(getCalibrationSummary)
export(getCohortCovariateData)
export(getDemographicSummary)
export(getEunomiaPlpData)
export(getPlpData)
export(getPredictionDistribution)
export(getThresholdSummary)
export(ici)
export(insertCsvToDatabase)
export(insertResultsToSqlite)
export(listAppend)
export(listCartesian)
export(loadPlpAnalysesJson)
export(loadPlpData)
export(loadPlpModel)
export(loadPlpResult)
export(loadPlpShareable)
export(loadPrediction)
export(migrateDataModel)
export(modelBasedConcordance)
export(outcomeSurvivalPlot)
export(pfi)
export(plotDemographicSummary)
export(plotF1Measure)
export(plotGeneralizability)
export(plotLearningCurve)
export(plotNetBenefit)
export(plotPlp)
export(plotPrecisionRecall)
export(plotPredictedPDF)
export(plotPredictionDistribution)
export(plotPreferencePDF)
export(plotSmoothCalibration)
export(plotSparseCalibration)
export(plotSparseCalibration2)
export(plotSparseRoc)
export(plotVariableScatterplot)
export(predictCyclops)
export(predictGlm)
export(predictPlp)
export(preprocessData)
export(recalibratePlp)
export(recalibratePlpRefit)
export(runMultiplePlp)
export(runPlp)
export(savePlpAnalysesJson)
export(savePlpData)
export(savePlpModel)
export(savePlpResult)
export(savePlpShareable)
export(savePrediction)
export(setAdaBoost)
export(setCoxModel)
export(setDecisionTree)
export(setGradientBoostingMachine)
export(setIterativeHardThresholding)
export(setLassoLogisticRegression)
export(setLightGBM)
export(setMLP)
export(setNaiveBayes)
export(setPythonEnvironment)
export(setRandomForest)
export(setRidgeRegression)
export(setSVM)
export(simulatePlpData)
export(sklearnFromJson)
export(sklearnToJson)
export(splitData)
export(toSparseM)
export(validateExternal)
export(validateMultiplePlp)
export(viewDatabaseResultPlp)
export(viewMultiplePlp)
export(viewPlp)
importFrom(dplyr,"%>%")
importFrom(rlang,.data)
